#' @keywords internal
"_PACKAGE"

#' @title hubeau: A package for retrieving data on the French databases on water 'Hub'Eau'
#'
#' @description
#' ```{r child = "man-roxygen/hubeau.md"}
#' ```
#'
#' @import utils
#' @name hubeau
#'
NULL
